;---------------------------------------------------------
; ABM MODEL RAZ13 project version 2021-09-09
;---------------------------------------------------------
; to be combined with corresponding R program
; (c) B.Bonté and K. Erdlenbruch
;extensions [gis csv]
;-------------------------
  ;-----MODEL FEATURES
  ;-------------------------


globals [
  ins
  outs
  nbLinks


  household-dataset
  or-intercept
  or-proba.flood
  or-consequence
  or-coping
  or-experience
  or-network

  adapted-last-tick
  proba-permanent ; probability of a new adaptation to be permanent; in the paper, only temporary adaptations are simulated

  flood
  visited-households ; numbers of visited household by the people centered policies
  flood-dates
  flood-types
  ]

breed [households household]
breed [regulators regulator]
directed-link-breed [connections connection]

regulators-own [
  regul-wealth
  regul-policy
  cost
]

households-own [
  ;-------------------------
  ;-----General Attributes--
  ;-------------------------
  hh.id
  wants-to-adapt

  ;--------------------------
  ;-----Area Attributes--
  ;--------------------------
  area ;  area informing about the risk level

  ;--------------------------
  ;-----Policies Attributes--
  ;--------------------------
  pr-td ; probability to be reached top down
  ps-td ; probability of success top down

  pr-pc ; probability to be reached people-centered
  ps-pc ; probability success people-centered

  ;---------------------
  ;-----PMT Attributes--
  ;---------------------
  proba.flood
  consequence
  coping
  experience
  network

 ;---------------------
  ;-----dynamic Attributes--
  ;---------------------
 N_i
  ;-------------------
  ; outcome variables
  ;-------------------
  adapted ; has one measure implemented
  adaptation.type ; Type of adaptation ("permanent" or "temporary")
  proba-adopt ; proba d'adoption d'une mesure
  damage-indiv
  earnings.indiv
  wealth.indiv
  min-wealth-indiv
]

;------------------------------------------------------------------------------------
;--------- BASIC METHOD FOR SIMULATION ----------------------------------------------
;------------------------------------------------------------------------------------

;------------------------------------
;-- Global setup method--------------
;------------------------------------

to setup
   clear-all
   setup-flood-sequences
  ; for experimental plan purposes
  ask patch 10 10 [sprout-regulators 1 [set color red
  set shape "sheep"
  set size 5
  regulator-setup]]
  ;create-network and create houshlods from R
end

to setup-1
  file-close-all ; Close any files open from last run
  ask regulators [ regulator-setup ]
  ask households [ household-compute-speed-action ]
  ask households [ household-update-network ]
  ask households [ household-update-proba-adopt ]
  ask households [ household-wealth ]
  ask households [ households-setup ]
  set adapted-last-tick sum [adapted] of households
  set proba-permanent 0
    ask households [if (adapted = 1) [set wants-to-adapt 1]] ; for consistency
  reset-ticks
end




;------------------------------------
;-- Global step method---------------
;------------------------------------

to go
  set visited-households 0
  set adapted-last-tick sum [adapted] of households
  ask households [ household-adapt-or-not ]
  ask households [ household-update-network ]
  ask households [ household-update-proba-adopt ]
  if com-policy = "td-rc" [ask households [ households-td-rc-policy ]]
  if com-policy = "pc-rc" [ask households [ households-pc-rc-policy ]]
  generate-flood
  if flood = "small" [ask households [ households-small-flood-experience ]]
  if flood = "big" [ask households [ households-big-flood-experience]]
  ask households [ households-compute-damage]
  if temporary-adaptations [ask households [ household-remove-adaptation ]]
  ask households [ household-update-wealth ]
  ask households [household-lose-attitudes ]
  ask regulators [ regulator-go ]
  tick
end

;---------------------------------------------------------------------------------
;--------- METHODS FOR REGULATOR -------------------------------------------------
;---------------------------------------------------------------------------------

;----------------------------------
;setting up methods for Regulator--
;----------------------------------

to regulator-setup
  set regul-policy com-policy
  set regul-wealth 0
  set visited-households 0
  set cost 0
end

;----------------------------------
;-----go up methods for Regulator--
;----------------------------------


to regulator-go
  if com-policy = "td-rc" [set cost 15000]
  if com-policy = "pc-rc" [set cost 200 * visited-households]
  set regul-wealth regul-wealth + r * (sum [wealth.indiv] of households) - cost
end

;------------------------------------------------------------------------------------
;--------- METHODS FOR HOUSEHOLDS -------------------------------------------------
;------------------------------------------------------------------------------------

;----------------------------------
;setting up methods for households
;----------------------------------

; made in R program

;----------------------------------
;step methods for households
;----------------------------------
to household-compute-speed-action
  set N_i N
end


to household-update-proba-adopt
  let Odds or-intercept * or-proba.flood ^ proba.flood *
  or-consequence ^ consequence *
  or-coping ^ coping *
  or-experience ^ experience *
  or-network ^ network
  set proba-adopt (Odds / (Odds + 1))
end


to household-update-network
  let myFriends [end2] of my-out-links
  let nbF length myFriends
  let fAdapt 0
  foreach myFriends [[f] ->
    set fAdapt fAdapt + [adapted] of f ]
  ifelse nbF = 0 [set network 0]
   [set network 1 + (fAdapt / nbF) * 4]
end

to household-adapt-or-not
  if adapted = 0 [
  ifelse random-float 1 < proba-adopt [
  set wants-to-adapt 1
  ][set wants-to-adapt 0]
  if wants-to-adapt = 1[
  if random-float 1 < (1 / N_i) [
  set adapted 1
  ifelse random-float 1 < proba-permanent [
    set adaptation.type "permanent"]
    [
      set adaptation.type "temporary"]
  ]
  ]
  ]
  ifelse adapted = 1
       [set color blue]
       [set color red]
end

to household-remove-adaptation
  if adapted = 1 [
  if adaptation.type = "temporary" [
    if random-float 1 < 1 / adaptation-duration[
      set adapted 0
      set wants-to-adapt 0
      set proba.flood 1
      set consequence 1
      set coping 1
      set experience 1
      set network 1
      set adaptation.type "NA"]
   ]
  ]
end

to household-lose-attitudes
  if adaptation.type = "temporary" [
    if random-float 1 < 3 / 10[
      set proba.flood proba.flood - 2
       if proba.flood < 0 [set proba.flood 1]
      set consequence consequence - 2
       if consequence < 0 [set consequence 1]
      set coping coping - 2
       if coping < 0 [set coping 1]
      set experience experience - 2
       if experience < 0 [set experience 1]
      set network network - 2 ]
       if network < 0 [set network 1]
  ]
end

to household-wealth
  ;set from R
  ;set wealth-indiv 1000 + random-float 49000
  ;set earnings-indiv 50 + random-float 950
  set damage-indiv 0
  set min-wealth-indiv wealth.indiv
end
;-----------------------------------------------------------------------
;step methods for households wrt com-policies and flood experience
;----------------------------------------------------------------------

to households-setup
  set pr-td random-normal 0.8 0.05
  set ps-td random-normal 0.2 0.05
  set pr-pc random-normal 0.2 0.05
  set ps-pc random-normal 0.8 0.05
end

to households-td-rc-policy
  let reached random-float 1 < pr-td
  if reached [
    if random-float 1 < ps-td [
    set proba.flood proba.flood + 1
    set consequence consequence + 1
    set coping coping + 2]
  ]
  households-correct-com
end


to households-pc-rc-policy
  let reached random-float 1 < pr-pc
  if reached [
    set visited-households visited-households + 1
    if random-float 1 < ps-pc [
      repeat 4 [
        let min-value min (list proba.flood consequence coping)
        ifelse proba.flood = min-value
        [set proba.flood proba.flood + 2 ]
        [ifelse consequence = min-value [set consequence consequence + 2 ][set coping coping + 2]]]
      ]
    ]
  households-correct-com
end

to households-small-flood-experience
    set proba.flood proba.flood + 1
    set experience experience + 1
  households-correct-com
end

to households-big-flood-experience
    set consequence consequence + 2
    set experience experience + 2
  households-correct-com
end


to households-correct-com
  if consequence > 5 [set consequence 5]
  if proba.flood > 5 [set proba.flood 5]
  if coping > 5 [set coping 5]
  if experience > 5 [set experience 5]
end


to households-compute-damage
  if flood = "small" [
    if adapted = 1 [
      if area = 1 [set damage-indiv  0]
      if area = 2 [set damage-indiv  0]
      if area = 3 [set damage-indiv 10610]
      if area = 4 [set damage-indiv 0]
       ]
    if adapted = 0 [
      if area = 1 [set damage-indiv  0]
      if area = 2 [set damage-indiv  10250]
      if area = 3 [set damage-indiv 16035]
      if area = 4 [set damage-indiv  0]
     ]
   ]
  if flood = "big"  [
    if adapted = 1 [
      if area = 1 [set damage-indiv 14545]
      if area = 2 [set damage-indiv  18540]
      if area = 3 [set damage-indiv 19995]
      if area = 4 [set damage-indiv  0]
       ]
    if adapted = 0 [
      if area = 1 [set damage-indiv  20570 ]
      if area = 2 [set damage-indiv  24635 ]
      if area = 3 [set damage-indiv  26090]
      if area = 4 [set damage-indiv  0]
    ]
  ]
  if flood = "no-flood" [set damage-indiv 0]
end

to household-update-wealth
 ifelse (wealth.indiv > 0) [set wealth.indiv wealth.indiv + earnings.indiv - damage-indiv - r * wealth.indiv][set wealth.indiv wealth.indiv + earnings.indiv - damage-indiv]
 if (wealth.indiv < min-wealth-indiv)[set min-wealth-indiv wealth.indiv]
end

;------------------------------------------------------------------------------------
;--------- METHOD TO SETUP THE WORLD -----------------------------------------------
;------------------------------------------------------------------------------------

;---------------------------------------
;-- Functions to create social network --
;---------------------------------------

to create-network
  let i 0
  repeat nbLinks [
    ask (one-of households with [item i ins = hh.id]) [create-connection-to (one-of households with [item i outs = hh.id])]
    set i i + 1
  ]
end

; ---------------
; flood generation
;---------
to generate-flood
  let dates item flood-sequence flood-dates
  let floods item flood-sequence flood-types
  ;show dates
  let num-flood 0
  set flood "no-flood"
  foreach dates [
    [date] ->
    if date = ticks [set flood item num-flood floods]
  set num-flood num-flood + 1
  ]
end

to setup-flood-sequences
  set flood-dates (list (list 2 3) (list 2 3) (list 20 21) (list 10 20) (list 10 20) (list 2 10 20) )
  set flood-types (list (list "small" "small") (list "big" "big") (list "big" "big") (list "big" "small") (list "small" "big") (list "small" "big" "big"))
end

;------------------------------------------------------------------------------------
; REPORTED FUNCTIONS
;----------------------------------------------------------------------------------
to-report findNumOfCol [colNames name]
  let i 0
  report i
end

to-report propAdapted
report count (households with [adapted = 1]) / count households
end

to-report propWantAdapt
report count (households with [wants-to-adapt = 1]) / count households
end

to-report permAdapted
  report count households with [adaptation.type = "permanent"] / (max list 1 (count households with [adapted = 1]))
end

to-report damage
  report sum [damage-indiv] of households
end

to-report wealth
  report sum [wealth.indiv] of households
end

to-report minWi
  report min [wealth.indiv] of households
end

to-report regulcosts
  report sum [cost] of regulators
end

to-report adapt-pmt
  let som 0
  ask households [set som som + household-proba-be-adapted]
  report som / (count households)
end

to-report household-proba-be-adapted
  let Odds or-intercept * or-proba.flood ^ proba.flood *
  or-consequence ^ consequence *
  or-coping ^ coping *
  or-experience ^ experience *
  or-network ^ network
  report (Odds / (Odds + 1))
end
@#$#@#$#@
GRAPHICS-WINDOW
419
11
928
521
-1
-1
1.0
1
10
1
1
1
0
0
0
1
0
500
0
500
0
0
1
ticks
30.0

BUTTON
29
24
98
57
NIL
setup-1
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
27
243
180
288
network-type
network-type
"n-closest-Friends" "15-small-world" "off"
1

TEXTBOX
28
207
178
237
Social Network\n-------------------------
12
0.0
1

CHOOSER
23
300
161
345
mean-degree
mean-degree
4 15 17
1

PLOT
432
539
941
780
Adaptation
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"adapted-households" 1.0 0 -13840069 true "" "plot count households with [adapted = 1] / (count households)"
"average-adapt-proba" 1.0 0 -16777216 true "" "plot mean [proba-adopt] of households"
"adaptation-rate" 1.0 0 -13345367 true "" "let ad-this-tick sum [adapted] of households\nplot (ad-this-tick - adapted-last-tick) / (count households)"
"pmt-adapted" 1.0 0 -2674135 true "" "plot adapt-pmt"

BUTTON
30
72
93
105
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
30
117
93
150
NIL
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
22
603
172
648
Communication strategies\n-------------------------\n
12
0.0
1

CHOOSER
15
674
153
719
com-policy
com-policy
"td-r" "td-rc" "pc-r" "pc-rc" "no-com"
3

SWITCH
15
748
212
781
temporary-adaptations
temporary-adaptations
0
1
-1000

TEXTBOX
26
376
176
406
Adaptation dynamics\n---------------------------------
12
0.0
1

SLIDER
26
409
139
442
N
N
1
10
0.0
1
1
year
HORIZONTAL

TEXTBOX
161
412
311
442
mean delay of installation\n
12
0.0
1

BUTTON
30
160
103
193
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
11
561
211
594
adaptation-duration
adaptation-duration
1
13
0.0
1
1
years
HORIZONTAL

PLOT
979
238
1302
405
Wealth and damage
NIL
NIL
0.0
10.0
200.0
10.0
true
true
"" ""
PENS
"wealth" 1.0 0 -11221820 true "" "plot wealth"
"damage" 1.0 1 -2674135 true "" "plot damage"

PLOT
1052
632
1248
782
Distribution of wealth
NIL
NIL
1000.0
50000.0
0.0
272.0
false
false
"set-histogram-num-bars 7\n" "set-plot-x-range round min ([wealth.indiv] of households) round max ([wealth.indiv] of households)\nset-histogram-num-bars 7"
PENS
"default" 1.0 1 -2674135 true "" "histogram [wealth.indiv] of households"

SLIDER
200
83
301
116
r
r
0
0.2
0.0
0.02
1
NIL
HORIZONTAL

PLOT
1053
436
1253
586
Regulator wealth
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "plot 0" "plot [regul-wealth] of one-of regulators"

SLIDER
199
140
342
173
flood-sequence
flood-sequence
0
5
0.0
1
1
NIL
HORIZONTAL

PLOT
1082
43
1282
193
plot 2
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot visited-households"

PLOT
1443
74
1643
224
Number of poor
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot count households with [wealth.indiv < 0]"

SLIDER
13
455
185
488
xi
xi
0
1
0.0
0.1
1
NIL
HORIZONTAL

TEXTBOX
205
464
355
492
weight of economic arguments in speed ofaction\n
11
0.0
1

SLIDER
12
505
184
538
omega
omega
0
50000
0.0
1
1
NIL
HORIZONTAL

TEXTBOX
205
515
355
543
cost of adaptation measure\n\n
11
0.0
1

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="test-td-policy" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="30"/>
    <metric>count (households with [adapted = 1]) / count households</metric>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;n-closest-Friends&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-down-com">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="test-com-policy" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="30"/>
    <metric>count (households with [adapted = 1]) / count households</metric>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;n-closest-Friends&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="com-policy">
      <value value="&quot;td-r&quot;"/>
      <value value="&quot;td-rc&quot;"/>
      <value value="&quot;pc-r&quot;"/>
      <value value="&quot;pc-rc&quot;"/>
      <value value="&quot;no-com&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="com-policy-test-init" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="30"/>
    <metric>count (households with [adapted = 1]) / count households</metric>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;n-closest-Friends&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="com-policy">
      <value value="&quot;td-r&quot;"/>
      <value value="&quot;td-rc&quot;"/>
      <value value="&quot;pc-r&quot;"/>
      <value value="&quot;pc-rc&quot;"/>
      <value value="&quot;no-com&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="haer-init">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="com-policy-tempadapt" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="30"/>
    <metric>count (households with [adapted = 1]) / count households</metric>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;n-closest-Friends&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="com-policy">
      <value value="&quot;td-r&quot;"/>
      <value value="&quot;td-rc&quot;"/>
      <value value="&quot;td-re&quot;"/>
      <value value="&quot;td-rew&quot;"/>
      <value value="&quot;pc-r&quot;"/>
      <value value="&quot;pc-rc&quot;"/>
      <value value="&quot;pc-re&quot;"/>
      <value value="&quot;pc-rew&quot;"/>
      <value value="&quot;no-com&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="temporary-adaptations">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="com-policy-tempadapt-haer-init2" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="30"/>
    <metric>count (households with [adapted = 1]) / count households</metric>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;n-closest-Friends&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="com-policy">
      <value value="&quot;td-r&quot;"/>
      <value value="&quot;td-rc&quot;"/>
      <value value="&quot;td-re&quot;"/>
      <value value="&quot;td-rew&quot;"/>
      <value value="&quot;pc-r&quot;"/>
      <value value="&quot;pc-rc&quot;"/>
      <value value="&quot;pc-re&quot;"/>
      <value value="&quot;pc-rew&quot;"/>
      <value value="&quot;no-com&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="temporary-adaptations">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="haer-init2">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="test" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="30"/>
    <metric>count (households with [adapted = 1]) / count households</metric>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;n-closest-Friends&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="raz-paper-1" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="30"/>
    <metric>propAdapted</metric>
    <metric>propWantAdapt</metric>
    <metric>permAdapted</metric>
    <steppedValueSet variable="setup-type" first="1" step="1" last="4"/>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;n-closest-Friends&quot;"/>
      <value value="&quot;15-small-world&quot;"/>
      <value value="&quot;off&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="com-policy">
      <value value="&quot;td-r&quot;"/>
      <value value="&quot;td-rc&quot;"/>
      <value value="&quot;pc-r&quot;"/>
      <value value="&quot;pc-rc&quot;"/>
      <value value="&quot;no-com&quot;"/>
      <value value="&quot;td-re&quot;"/>
      <value value="&quot;pc-re&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="temporary-adaptations">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="T">
      <value value="5"/>
      <value value="10"/>
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="raz-paper-2" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="30"/>
    <metric>propAdapted</metric>
    <metric>propWantAdapt</metric>
    <metric>permAdapted</metric>
    <steppedValueSet variable="setup-type" first="1" step="1" last="5"/>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;n-closest-Friends&quot;"/>
      <value value="&quot;15-small-world&quot;"/>
      <value value="&quot;off&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="com-policy">
      <value value="&quot;td-r&quot;"/>
      <value value="&quot;td-rc&quot;"/>
      <value value="&quot;pc-r&quot;"/>
      <value value="&quot;pc-rc&quot;"/>
      <value value="&quot;no-com&quot;"/>
      <value value="&quot;td-re&quot;"/>
      <value value="&quot;pc-re&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="temporary-adaptations">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="T">
      <value value="5"/>
      <value value="10"/>
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-duration">
      <value value="3"/>
      <value value="7"/>
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="test-sobol" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="15"/>
    <metric>propAdapted</metric>
    <metric>propWantAdapt</metric>
    <metric>permAdapted</metric>
    <enumeratedValueSet variable="setup-type">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;15-small-world&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-degree">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="com-policy">
      <value value="&quot;pc-rc&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="temporary-adaptations">
      <value value="true"/>
    </enumeratedValueSet>
    <steppedValueSet variable="T" first="5" step="1" last="15"/>
    <steppedValueSet variable="N" first="1" step="1" last="10"/>
    <steppedValueSet variable="adaptation-duration" first="3" step="1" last="13"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
