##################################################
# Program for ABM of RAZ 13 project############## 
# Authors: B. Bont #############################
#################################################
### Libraries
library(igraph)
library(intergraph)
library(tcltk)
library(GGally)
library(sp)
library(dplyr)

createNetwork <- function(ids,x,y, 
                          shortDist = 50
                          ){
  #x <- households$xcor
  #y <- households$ycor
  #ids <- households$hh.id
  
#shortDist <- sqrt(500*500 / length(ids)) * 2
deg <- 5

loc <- cbind(x,y)

#Matrix of distances
dists <- spDists(loc)

#Create a graph with all nearby nodes
#####################################
#Adjacency Matrix (adding 1 meter otherwise, "0" distances are not considered as linked in the graph)
areNeighbours <- dists < shortDist

adj <- (dists + 1) * areNeighbours

#Remove all edges except "deg" close nodes randomly choosen for each node

matElaguage <- function(n){
  l <- adj[n,]
  linksIndexes <- sample(which(l > 0),5)
  newLine <- matrix(0,1,length(l))
  newLine[1,linksIndexes] <- l[linksIndexes]
  return(newLine)
}

adj2 <- sapply(X = seq(dim(adj)[1]), matElaguage)

adj <- adj2

#Create a valuedcomplete graph valued by the distances between two nodes
g <- graph_from_adjacency_matrix(adj, 
                                 mode="directed",
                                 diag=FALSE,
                                 weighted ="distance")
V(g)$name <- ids


#V(g)$size <- 2
#E(g)$curved <- 1
#plot(g, vertex.label=NA, edge.arrow.size=0.1)

#Rewire only one edge by cluster to have a connected graph
vertexComps <- (g %>% components())$membership
comps <- unique(vertexComps)
for (i in 1:1){
  for (c in comps[1:(length(comps))]){
    v <- V(g)[sample(which(vertexComps == c),1)]
    v2 <- V(g)[sample(which(vertexComps == (((c + i - 1) %% length(comps))+1)),1)]
    g <- g - sample(incident(g,v,mode="out"),1)
    g <- g + edge(c(v,v2))
  }
}

#V(g)$size <- 2
#E(g)$curved <- 1
#plot(g, vertex.label=NA, edge.arrow.size=0.1)

#Reorganize the graph to have a nice circle
ordr <- as.data.frame(cbind(sort(dists[1,],index.return=T)$ix, ids))
ordr <- arrange(ordr, V1)$ids
g <- permute(g, ordr)

#Draw the graph as a Circle
#g$layout <- layout_with_dh
#g$layout <- layout_in_circle
#V(g)$size <- 4
#E(g)$curved <- 1
#plot(g, vertex.label=NA, edge.arrow.size=0.1)

g1 <- rewire(g,each_edge(prob = 0.015))
#g1$layout <- layout_in_circle
#V(g1)$size <- 1
#E(g1)$curved <- 1
#plot(g2, vertex.label=NA, edge.arrow.size=0.1)

#C1<- transitivity(g)
#L1 <- mean_distance(g1)

swNet <- g1
el <- as_edgelist(swNet,names=T)
return(el)

}

